@@ -29,7 +29,7 @@ if [ -d /sys/bus/pci/devices ] && \
 	anna-install virtio-modules || true
 fi
 
-if [ -x /sbin/depmod ]; then
+if [ -x /usr/sbin/depmod ]; then
 	depmod -a > /dev/null 2>&1 || true
 fi
 
@@ -506,6 +506,11 @@ if [ -n "$(list-devices cd; list-devices maybe-usb-floppy)" ]; then
 	apt-install eject || true
 fi
 
+# Install opal-prd for OpenPOWER machines LP: #1555904
+if [ -d /sys/firmware/devicetree/base/ibm,opal/diagnostics ]; then
+	apt-install opal-prd || true
+fi
+
 db_progress SET $MAX_STEPS
 db_progress STOP
 
@@ -513,7 +518,11 @@ if [ -n "$MISSING_MODULES_LIST" ]; then
 	log "Missing modules '$MISSING_MODULES_LIST"
 fi
 
-check-missing-firmware
+if [ "$CHECK_MISSING_FIRMWARE" != 0 ]; then
+	check-missing-firmware
+else
+	log "skipping check-missing-firmware as requested by the caller"
+fi
 
 sysfs-update-devnames
 
